# Ribasim Python

The Ribasim Python package (named `ribasim`) aims to make it easy to build, update and analyze Ribasim models
programmatically.

The Ribasim QGIS plugin allows users to construct a model from scratch without programming.
For specific tasks, like adding observed rainfall timeseries, it can be faster to use
Python instead.

One can also use Ribasim Python to build entire models from base data, such that your model
setup is fully reproducible.

The package is [registered in PyPI](https://pypi.org/project/ribasim/) and can therefore
be installed with `pip install ribasim`.

For documentation please see the [examples](https://deltares.github.io/Ribasim/python/examples.html) and [API reference](https://deltares.github.io/Ribasim/python/reference/).

# Contributing

For the developer docs please have a look at https://deltares.github.io/Ribasim/python/developer.html
